import React from 'react';
import { Docs, DocsExample, DocProps, DocsP } from '@doc-utils';
import propsSrc from './generated-props.json';
import examples from './generated-examples.json';
import { RMWCProvider } from '.';
export default function () {
    return (React.createElement(Docs, { title: "Provider", lead: "A component that provides global configuration for RMWC.", module: "@rmwc/provider", styles: [], examples: examples },
        React.createElement(DocsP, null, "You can wrap your top level App component with RMWC provider to set global configuration options. Just pass the options in as props."),
        React.createElement(DocsExample, { codeOnly: true }, 
        /* jsx */ "\n          import React from 'react';\n          import * as ReactDOM from 'react-dom';\n          import App from './App'; // your main app component\n          import { RMWCProvider } from '@rmwc/provider';\n\n          // This example disables ripples globally by default\n          ReactDOM.render(\n            <RMWCProvider\n              // Globally disable ripples\n              ripple={false}\n              // Global options for icons\n              // Takes the same options as the icon component\n              icon={{\n                basename: 'material-icons'\n              }}\n              // Global options for typography\n              // allows mapping of a defaultTag or specific classes\n              // See the Typography docs for more info\n              typography={{\n                defaultTag: 'div',\n                headline1: 'h1'\n              }}\n              // Global options for tooltips\n              // Takes most of the options for tooltips\n              // See the Tooltip docs for more info\n              tootlip={{\n                align: 'right'\n              }}\n            >\n              <App />\n            </RMWCProvider>,\n            document.getElementById('root'),\n          );\n        "),
        React.createElement(DocProps, { src: propsSrc, components: [{ displayName: 'RMWCProvider', component: RMWCProvider }] })));
}
